@@ -39,14 +39,20 @@ the following code snippet demonstrates a typical implementation::
             super().__init__(**kwargs)
 
         def open(self):
+            self.activate_esc_key_close()
             self.activate_modal()
 
         def close(self):
+            self.deactivate_esc_key_close()
             self.deactivate_modal()
 
 
-to activate the modal mode call the method :meth:`~ModalBehavior.activate_modal`. the modal mode can be deactivated by
-calling the :meth:`~ModalBehavior.deactivate_modal` method.
+calling the method :meth:`~ModalBehavior.activate_esc_key_close` in the `open` method of your container class allows
+the user to close the popup by pressing the Escape key (or Back on Android). this optional feature can then be reverted
+by calling the :meth:`~.deactivate_esc_key_close()` method in your `close` method.
+
+to additionally activate the modal mode call the method :meth:`~ModalBehavior.activate_modal`. the modal mode can be
+deactivated by calling the :meth:`.deactivate_modal` method.
 
 all touch, mouse and keyboard user interactions will be consumed or filtered after activating the modal mode. therefore
 it is recommended to also visually change the GUI while in the modal mode, which has to be implemented by the mixing-in
@@ -129,6 +135,7 @@ list in your `buildozer.spec` file.
 import os
 import traceback
 from copy import deepcopy
+from functools import partial
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 # noinspection PyProtectedMember
@@ -143,6 +150,7 @@ from kivy.metrics import sp
 from kivy.properties import (                                                                           # type: ignore
     BooleanProperty, DictProperty, ListProperty, NumericProperty, ObjectProperty, StringProperty)
 from kivy.uix.behaviors import ButtonBehavior, ToggleButtonBehavior                                     # type: ignore
+from kivy.uix.dropdown import DropDown                                                                  # type: ignore
 from kivy.uix.floatlayout import FloatLayout                                                            # type: ignore
 from kivy.uix.image import Image                                                                        # type: ignore
 from kivy.uix.relativelayout import RelativeLayout                                                      # type: ignore
@@ -152,6 +160,7 @@ from kivy.uix.widget import Widget
 
 from ae.base import snake_to_camel                                                                      # type: ignore
 from ae.dynamicod import try_eval                                                                       # type: ignore
+from ae.gui_app import flow_action                                                                      # type: ignore
 from ae.gui_help import (                                                                               # type: ignore
     REGISTERED_TOURS, anchor_layout_x, anchor_layout_y, anchor_points, anchor_spec, help_id_tour_class,
     HelpAppBase, OnboardingTour, TourBase)
@@ -159,7 +168,7 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.3.39'
+__version__ = '0.3.40'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -332,16 +341,31 @@ class AbsolutePosSizeBinder:
 
 
 class ModalBehavior:                                                                                # pragma: no cover
-    """ mix-in to provide a modal mode to a container widget.
+    """ mix-in to allow close on Escape/Back key and to optionally provide a modal mode to a container widget.
 
     to make the container widget's modal state more obvious, add in your container widget an overlay color with an
     alpha between 0.3 and 0.9, together with the following canvas instructions:
 
         canvas:
             Color:
-                rgba: root.my_overlay_color[:3] + [root.my_overlay_color[-1] if root._window else 0]
+                rgba: root.my_overlay_color[:3] + [root.my_overlay_color[-1] if self.is_modal else 0]
             Rectangle:
-                size: self._window.size if self._window else (0, 0)
+                size: Window.size if self.is_modal else (0, 0)
+
+    two rectangles will be needed to not overlay/fade-out the help activator button:
+
+        canvas:
+            Color:
+                rgba: self.my_overlay_color[:3] + [self.my_overlay_color[-1] if self.is_modal else 0]
+            Rectangle:
+                size:
+                    Window.width if self.is_modal else 0, \
+                    Window.height - app.main_app.help_activator.height if self.is_modal else 0
+            Rectangle:
+                pos: app.main_app.help_activator.right, app.main_app.help_activator.y
+                size:
+                    Window.width - app.main_app.help_activator.width if self.is_modal else 0, \
+                    app.main_app.help_activator.height
 
     """
     # abstracts provided by Kivy's :class:`~kivy.uix.widget.Widget` class or by the mixing-in container widget class.
@@ -351,6 +375,7 @@ class ModalBehavior:
     disabled: bool              #: disabled property of :class:`~kivy.uix.widget.Widget`
     fbind: Callable             #: fast binding method of :class:`~kivy.uix.widget.Widget`
     funbind: Callable           #: fast unbinding method of :class:`~kivy.uix.widget.Widget`
+    unbind_uid: Callable        #: even faster unbinding method of :class:`~kivy.uix.widget.Widget`
 
     auto_dismiss = BooleanProperty()
     """ determines if the container is automatically dismissed when the user hits the Esc/Back key or clicks outside it.
@@ -358,95 +383,263 @@ class ModalBehavior:
     :attr:`auto_dismiss` is a :class:`~kivy.properties.BooleanProperty` and defaults to True.
     """
 
-    _fast_bound: List = []                                  #: list of arg tuples for fbind/funbind
-    _touch_started_inside: Optional[bool] = None            #: flag if touch started inside self (the container widget)
-    _window = ObjectProperty(allownone=True, rebind=True)   #: internal flag to store main window instance if open
+    is_modal = BooleanProperty(defaultvalue=False)
+    """ flag if modal mode is active. use :meth:`.activate_modal` and :meth:`.deactivate_modal` to change this value.
 
-    def activate_modal(self, align_center: bool = True):
-        """ activate or renew modal mode for the mixing-in container widget.
+    :attr:`is_modal` is a :class:`~kivy.properties.BooleanProperty` and defaults to False.
+    """
 
-        :param align_center:    pass False to prevent the automatic alignment of :attr:`center` to
-                                :attr:`~kivy.core.window.Window.center`
-                                on reposition or resize of self or on resize of :class:`~kivy.core.window.Window`.
-        """
-        self.deactivate_modal()
-
-        Window.add_widget(self)
-        Window.bind(on_key_down=self._on_key_down)
-
-        if align_center:
-            Window.bind(on_resize=self._align_center)
-
-            fast_bind = self.fbind                                                  # pylint: disable=no-member
-            self._fast_bound = [('center', self._align_center), ('size', self._align_center)]
-            for fast_binding in self._fast_bound:
-                fast_bind(*fast_binding)
-
-        self._window = Window
+    _center_aligned: bool = False                           #: True if self will be repositioned to Window center
+    _fast_bound_center_uid: int = 0                         #: if of center (pos and size) fbind/unbind_uid
+    _touch_started_inside: Optional[bool] = None            #: flag if touch started inside this widget or -group
 
     def _align_center(self, *_args):
-        """ reposition container on window resize. """
-        if self._window:
+        """ reposition container to Window center.
+
+        :param _args:           unused (passed only on bound window resize events)
+        """
+        if self._center_aligned and self.is_modal:
             self.center = Window.center
 
-    def deactivate_modal(self):
-        """ de-activate modal mode for the mixing-in container. """
-        if self._fast_bound:
-            fast_unbind = self.funbind                                              # pylint: disable=no-member
-            for fast_unbinding in self._fast_bound:
-                fast_unbind(*fast_unbinding)
-            self._fast_bound = []
-
-            if self._window:
-                Window.unbind(on_resize=self._align_center)
-
-        if self._window:
-            Window.unbind(on_resize=self._align_center, on_key_down=self._on_key_down)
-            Window.remove_widget(self)
-        self._window = None
-
     def _on_key_down(self, _window, key, _scancode, _codepoint, _modifiers):
         """ close/dismiss this popup if back/Esc key get pressed - allowing stacking with DropDown/FlowDropDown. """
-        if key == 27 and self.auto_dismiss and self._window:
+        if key == 27 and self.auto_dismiss and self.is_modal:
             if not App.get_running_app().tour_layout:   # prevent close/dismiss by Esc-key if app tour is active/running
                 self.close()
             return True
         return False
 
+    def activate_esc_key_close(self):
+        """ activate key press handler, calling self.close() if Escape/Back key get pressed. """
+        Window.bind(on_key_down=self._on_key_down)
+
+    def activate_modal(self, align_center: bool = True):
+        """ activate or renew modal mode for the mixing-in container widget.
+
+        :param align_center:    pass False to prevent the automatic alignment of :attr:`~kivy.uix.widget.Widget.center`
+                                to :attr:`~kivy.core.window.Window.center` on reposition or resize of self
+                                or on resize of :class:`~kivy.core.window.Window`.
+        """
+        self.deactivate_modal()
+
+        Window.add_widget(self)
+
+        if align_center:
+            Window.bind(on_resize=self._align_center)
+            self._center_aligned = align_center
+            # binding center includes notification event on change of :attr:`~kivy.uix.widget.Widget.pos` and of `size`
+            self._fast_bound_center_uid = self.fbind('center', self._align_center)          # pylint: disable=no-member
+
+        self.is_modal = True
+
+    def deactivate_esc_key_close(self):
+        """ deactivate keyboard event handler, activated via :meth:`.activate_esc_key_close`. """
+        Window.unbind(on_key_down=self._on_key_down)
+
+    def deactivate_modal(self):
+        """ de-activate modal mode for the mixing-in container. """
+        if self._fast_bound_center_uid:
+            self.unbind_uid('center', self._fast_bound_center_uid)                          # pylint: disable=no-member
+            Window.unbind(on_resize=self._align_center)
+            self._fast_bound_center_uid = 0
+
+        if self._center_aligned:
+            Window.unbind(on_resize=self._align_center)
+            self._center_aligned = False
+
+        if self.is_modal:
+            Window.remove_widget(self)
+        self.is_modal = False
+
     def on_touch_down(self, touch: MotionEvent) -> bool:
         """ touch down event handler, prevents the processing of a touch on the help activator widget by this popup.
 
         :param touch:           motion/touch event data.
         :return:                True if event got processed/used.
         """
+        self._touch_started_inside = self.touch_pos_is_inside(touch.pos)
+
         if App.get_running_app().main_app.help_activator.collide_point(*touch.pos):
             return False  # allow help activator button to process this touch down event
             # .. and leave self._touch_started_inside == None to not initiate popup.close/dismiss in on_touch_up
-        self._touch_started_inside = self.collide_point(*touch.pos)
 
-        # pylint: disable=superfluous-parens # false positive
-        if not (self.disabled if self._touch_started_inside else self.auto_dismiss):
-            super().on_touch_down(touch)    # type: ignore # pylint: disable=no-member # false positive
+        if self.disabled if self._touch_started_inside else self.auto_dismiss:
+            return self.is_modal
 
-        return True
+        return super().on_touch_down(touch)    # type: ignore # pylint: disable=no-member # false positive
 
-    def on_touch_move(self, touch):
+    def on_touch_move(self, touch: MotionEvent) -> bool:
         """ touch move event handler. """
-        if not self.auto_dismiss or self._touch_started_inside:
-            # noinspection PyUnresolvedReferences
-            super().on_touch_move(touch)    # pylint: disable=no-member # false positive
-        return True
+        if self.disabled if self._touch_started_inside else self.auto_dismiss:
+            return self.is_modal
 
-    def on_touch_up(self, touch):
+        # noinspection PyUnresolvedReferences
+        return super().on_touch_move(touch)    # type: ignore # pylint: disable=no-member # false positive
+
+    def on_touch_up(self, touch: MotionEvent) -> bool:
         """ touch up event handler. """
         if self.auto_dismiss and self._touch_started_inside is False:
             self.close()
         else:
             # noinspection PyUnresolvedReferences
-            super().on_touch_up(touch)      # pylint: disable=no-member # false positive
+            super().on_touch_up(touch)      # type: ignore # pylint: disable=no-member # false positive
         self._touch_started_inside = None
         return True
 
+    def touch_pos_is_inside(self, pos: List[float]) -> bool:
+        """ check if the touch pos is inside of this widget or a group of sub-widgets.
+
+        :param pos:             touch position (x, y) in window coordinates.
+        :return:                True if this widget or group would process a touch event at :paramref:`.pos`.
+        """
+        return self.collide_point(*pos)
+
+
+class SlideSelectBehavior:                                                                        # pragma: no cover
+    """ quickly navigate in sub-/menus, starting with a long touch, then slide to the menu item to select and release.
+
+    the ``slide_select`` feature of this class allows a quicker select of any menu item, by opening any popup via the
+    :meth:`~ae.kivy_app.TouchableBehavior.on_long_tap` event, then move the pointer/finger onto the menu item to select
+    to finally release the touch. to enable this feature specify the touch event in the `touch_event` key of the
+    `popup_kwargs` dict in the :meth:`~ae.gui_app.MainAppBase.change_flow` call, e.g. by adding the following lines in
+    your kv code onto the :class:`~ae.kivy_app.FlowButton`/:class:`~ae.kivy_app.FlowToggler` that is opening the popup:
+
+        on_long_tap:
+            app.main_app.change_flow(id_of_flow('open', 'my_menu'),
+            **update_tap_kwargs(self, popup_kwargs=dict(touch_event=args[1])))
+
+    .. note::
+        has to be inherited (to be in the MRO) before :class:`~kivy.uix.behaviors.ButtonBehavior`, respectively
+        :class:`~kivy.uix.behaviors.ToggleButtonBehavior`, for the touch event get grabbed properly.
+    """
+    # abstracts of mixing-in class; e.g. from :class:`~kivy.widget.Widget`, :class:`~ae.kivy_glsl.ShadersMixin`,
+    # :class:`~kivy.uix.dropdown.DropDown` and :class:`~kivy.uix.behaviors.ButtonBehavior`.
+    attach_to: Optional[Widget]
+    close: Callable
+    collide_point: Callable
+    dispatch: Callable
+    to_widget: Callable
+
+    def __init__(self, **kwargs):
+        """ set normal pressed state shader on widget initialization. """
+        self._layout_finished: bool = True
+        self._opened_item: Optional[Widget] = None
+        self._touch_moved_outside: bool = False
+        self.main_app = App.get_running_app().main_app
+
+        # noinspection PyUnresolvedReferences
+        super().__init__(**kwargs)      # pylint: disable=no-member
+
+    @staticmethod
+    def _cancel_slide_select_closer(touch):
+        slide_select_closer = touch.ud.pop('slide_select_closer', None)
+        if slide_select_closer:
+            Clock.unschedule(slide_select_closer)  # alternatively: slide_select_closer.cancel()
+
+    @staticmethod
+    def _cancel_slide_select_opener(touch):
+        slide_select_opener = touch.ud.pop('slide_select_opener', None)
+        if slide_select_opener:
+            Clock.unschedule(slide_select_opener)  # alternatively: slide_select_opener.cancel()
+
+    def _grab_and_open(self, touch: MotionEvent, item: Widget, first_close: Widget, *_args):
+        if first_close:  # moved over another menu item of the parent menu then close
+            touch.ungrab(first_close)
+            first_close.close()  # .. the foremost sub-menu and open the sibling sub-menu instead
+
+        if not self.main_app.change_flow(item.tap_flow_id, **item.tap_kwargs):
+            return
+
+        self._opened_item = item
+        sub_menu = Window.children[0]           # sub-menu just opened above via change_flow
+        touch.grab(sub_menu)
+        # allow to pass :meth:`ModalBehavior.on_touch_move` for ``slide_select``
+        sub_menu._touch_started_inside = True
+
+    @staticmethod
+    def _ungrab_and_close(touch: MotionEvent, popup: Union[Widget, 'SlideSelectBehavior'], *_args):
+        touch.ungrab(popup)
+        # noinspection PyProtectedMember
+        Window.children[1]._opened_item = None
+        popup.close()
+
+    def on_touch_move(self, touch: MotionEvent) -> bool:
+        """ disable long touch on mouse/finger moves.
+
+        :param touch:           motion/touch event data.
+        :return:                True if event got processed/used.
+        """
+        is_dropdown = isinstance(self, DropDown)
+        opener: Optional[Widget] = self.attach_to if is_dropdown else self
+        in_opener = opener and opener.collide_point(*touch.pos)
+        if opener and not in_opener:
+            opener._touch_moved_outside = True
+
+        # ``slide_select`` of menu-items/children of :class:`FlowDropDown`, :class:`FlowSelector` and :class:`FlowPopup`
+        self._cancel_slide_select_closer(touch)
+        self._cancel_slide_select_opener(touch)
+        mnu_items = getattr(self, 'menu_items', None)
+        if mnu_items and self._layout_finished:
+            win_chi = Window.children[:2]
+            foremost_popup = self is win_chi[0]
+
+            if foremost_popup and in_opener and opener._touch_moved_outside:    # type: ignore # false positive
+                touch.ud['slide_select_closer'] = slide_select_closer = partial(self._ungrab_and_close, touch, self)
+                Clock.schedule_once(slide_select_closer, 0.69)
+
+            if self in win_chi:
+                wid_pos = self.to_widget(*touch.pos)
+                col_items = [item for item in mnu_items
+                             if item != self._opened_item
+                             and item.collide_point(*wid_pos)
+                             and flow_action(getattr(item, 'tap_flow_id', "")) == 'open']
+                if len(col_items) == 1:  # single non-overlapping item found
+                    touch.ud['slide_select_opener'] = slide_select_opener = partial(
+                        self._grab_and_open, touch, col_items[0], None if foremost_popup else win_chi[0])
+                    Clock.schedule_once(slide_select_opener, 0.39)
+                    return True
+                if foremost_popup:
+                    widgets = mnu_items + [self.attach_to if is_dropdown else self]
+                    min_x, min_y, width, height = self.main_app.widgets_enclosing_rectangle(widgets)
+                    if not (min_x <= touch.x <= min_x + width and min_y <= touch.y <= min_y + height):
+                        self._ungrab_and_close(touch, self)
+                        return True
+
+        # noinspection PyUnresolvedReferences
+        return super().on_touch_move(touch)     # type: ignore # pylint: disable=no-member
+
+    def on_touch_up(self, touch: MotionEvent) -> bool:
+        """ disable long touch on mouse/finger up.
+
+        :param touch:           motion/touch event data.
+        :return:                True if event got processed/used.
+        """
+        self._cancel_slide_select_closer(touch)
+        self._cancel_slide_select_opener(touch)
+        self._opened_item = None
+
+        if touch.ud.pop('is_long_tap', False):
+            items = getattr(self, 'menu_items', None)
+            if items and self._layout_finished and self == Window.children[0]:
+                for item in items:
+                    if item.collide_point(*item.to_widget(*touch.pos)):      # slide_select touch released on menu item
+                        if hasattr(item, 'on_release'):
+                            if item not in touch.ud:    # prevent multiple dispatch of on_release
+                                item.dispatch('on_release')
+                                return True
+                        elif hasattr(item, 'focus'):
+                            item.unfocus_on_touch = False
+                            item.focus = True
+                            return True
+                        elif hasattr(item, 'value_pos'):
+                            item.value_pos = touch.pos
+                            return True
+                        else:
+                            break
+
+        # noinspection PyUnresolvedReferences
+        return super().on_touch_up(touch)   # type: ignore # pylint: disable=no-member; does touch.ungrab(self)
+
 
 class Tooltip(ScrollView):                                                           # pragma: no cover
     """ semi-transparent and optional click-through container to display help and tour page texts. """
@@ -524,9 +717,11 @@ class Tooltip(ScrollView):
 
         wid = self.targeted_widget
         self._targeted_binder = twb = AbsolutePosSizeBinder(wid, bind_window_size=True)
-        twb.size_to_attribute(self, 'pos', self._actual_pos)
+        twb.size_to_attribute(self, 'pos', self._actual_pos)    # ensure position update on wid.size and .pos changes
         twb.pos_to_attribute(self, 'pos', self._actual_pos)
 
+        self.pos = self._actual_pos()                           # initial reposition of tooltip window
+
     def on_touch_down(self, touch: MotionEvent) -> bool:
         """ check for additional events added by this class.
 
@@ -1258,6 +1453,7 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         ani.start(self.ids.tooltip)
         self._tooltip_animation = ani
 
+        self.activate_esc_key_close()
         self.activate_modal()
 
         return True
@@ -1280,4 +1476,5 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         main_app.help_activator.ani_stop()
         main_app.change_observable('tour_layout', None)    # set app./main_app.tour_layout to None
 
+        self.deactivate_esc_key_close()
         self.deactivate_modal()
